@@ -141,6 +141,7 @@ class CacheTransport(httpx.BaseTransport):
                     response=res,
                     request=httpcore_request,
                     cached=True,
+                    revalidated=False,
                     metadata=metadata,
                 )
 
@@ -166,6 +167,7 @@ class CacheTransport(httpx.BaseTransport):
                             response=stored_response,
                             request=httpcore_request,
                             cached=True,
+                            revalidated=False,
                             metadata=metadata,
                         )
                     raise  # pragma: no cover
@@ -191,6 +193,7 @@ class CacheTransport(httpx.BaseTransport):
                     response=final_httpcore_response,
                     request=httpcore_request,
                     cached=revalidation_response.status_code == 304,
+                    revalidated=True,
                     metadata=metadata,
                 )
 
@@ -217,6 +220,7 @@ class CacheTransport(httpx.BaseTransport):
             response=httpcore_regular_response,
             request=httpcore_request,
             cached=False,
+            revalidated=False,
         )
 
     def _create_hishel_response(
@@ -225,6 +229,7 @@ class CacheTransport(httpx.BaseTransport):
         response: httpcore.Response,
         request: httpcore.Request,
         cached: bool,
+        revalidated: bool,
         metadata: Metadata | None = None,
     ) -> Response:
         if cached:
@@ -235,6 +240,7 @@ class CacheTransport(httpx.BaseTransport):
             response.extensions["cache_metadata"] = metadata  # type: ignore[index]
         else:
             response.extensions["from_cache"] = False  # type: ignore[index]
+        response.extensions["revalidated"] = revalidated  # type: ignore[index]
         return Response(
             status_code=response.status,
             headers=response.headers,
@@ -246,7 +252,7 @@ class CacheTransport(httpx.BaseTransport):
         self._storage.close()
         self._transport.close()
 
-    def __enter__(self) -> "Self":
+    def __enter__(self) -> Self:
         return self
 
     def __exit__(
